<?php

namespace Bixo\Lead\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Lead\Actions\BlacklistAction;
use Bixo\Lead\Http\Requests\BlacklistActionRequest;
use Bixo\Lead\Http\Resources\BlacklistResource;
use Bixo\Lead\Models\Blacklist;

/**
 * Admin web controller class.
 */
class BlacklistActionController extends BaseController
{

    /**
     * Action controller function for blacklist.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BlacklistActionRequest $request, Blacklist $blacklist, $action)
    {
        try {
            $request = $request->all();
            $blacklist = BlacklistAction::run($action, $blacklist, $request);

            $data = new BlacklistResource($blacklist);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('lead::blacklist.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('lead/blacklist/' . $blacklist->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead/blacklist/' . $blacklist->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
