<?php

namespace Bixo\Lead\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Lead\Forms\Blacklist as BlacklistForm;
use Bixo\Lead\Http\Requests\BlacklistResourceRequest;
use Bixo\Lead\Http\Resources\BlacklistResource;
use Bixo\Lead\Http\Resources\BlacklistsCollection;
use Bixo\Lead\Models\Blacklist;
use Bixo\Lead\Actions\BlacklistAction;
use Bixo\Lead\Actions\BlacklistActions;


/**
 * Resource controller class for blacklist.
 */
class BlacklistResourceController extends BaseController
{

    /**
     * Initialize blacklist resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = BlacklistForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.lead.modules'), 'lead', guard_url('lead'));
            return $next($request);
        });
    }

    /**
     * Display a list of blacklist.
     *
     * @return Response
     */
    public function index(BlacklistResourceRequest $request)
    {
        $request = $request->all();
        $page = BlacklistActions::run('paginate', $request);

        $data = new BlacklistsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('lead::blacklist.names'))
            ->view('lead::blacklist.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display blacklist.
     *
     * @param Request $request
     * @param Model   $blacklist
     *
     * @return Response
     */
    public function show(BlacklistResourceRequest $request, Blacklist $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new BlacklistResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('lead::blacklist.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('lead::blacklist.show')
            ->output();
    }

    /**
     * Show the form for creating a new blacklist.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BlacklistResourceRequest $request, Blacklist $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new BlacklistResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('lead::blacklist.name'))
            ->view('lead::blacklist.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new blacklist.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BlacklistResourceRequest $request, Blacklist $model)
    {
        try {
            $request = $request->all();
            $model = BlacklistAction::run('store', $model, $request);
            $data = new BlacklistResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('lead::blacklist.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('lead/blacklist/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/lead/blacklist'))
                ->redirect();
        }

    }

    /**
     * Show blacklist for editing.
     *
     * @param Request $request
     * @param Model   $blacklist
     *
     * @return Response
     */
    public function edit(BlacklistResourceRequest $request, Blacklist $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new BlacklistResource($model);
        // return view('lead::blacklist.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('lead::blacklist.name'))
            ->view('lead::blacklist.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the blacklist.
     *
     * @param Request $request
     * @param Model   $blacklist
     *
     * @return Response
     */
    public function update(BlacklistResourceRequest $request, Blacklist $model)
    {
        try {
            $request = $request->all();
            $model = BlacklistAction::run('update', $model, $request);
            $data = new BlacklistResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('lead::blacklist.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('lead/blacklist/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead/blacklist/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the blacklist.
     *
     * @param Model   $blacklist
     *
     * @return Response
     */
    public function destroy(BlacklistResourceRequest $request, Blacklist $model)
    {
        try {

            $request = $request->all();
            $model = BlacklistAction::run('destroy', $model, $request);
            $data = new BlacklistResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lead::blacklist.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('lead/blacklist/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead/blacklist/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
