<?php

namespace Bixo\Lead\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Lead\Events\BlacklistAction as BlacklistActionEvent;
use Bixo\Lead\Notifications\BlacklistAction as BlacklistActionNotification;
use Litepie\Actions\Concerns\AsAction;

class BlacklistAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the BlacklistActionEvent.
     *
     * @param   BlacklistActionEvent  $event
     * @return mixed
     */
    public function handle(BlacklistActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $blacklist.
     *
     * @param   BlacklistActionEvent  $event
     * @return void
     */
    public function create(BlacklistActionEvent $event)
    {
        $client = $event->blacklist->client;
        Notification::send($client, new BlacklistActionNotification($event));
    }

    /**
     * Handle the BlacklistActionEvent as a listener.
     *
     * @param   BlacklistActionEvent  $event
     * @return mixed
     */
    public function asListener(BlacklistActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   BlacklistActionEvent  $event
     * @return bool
     */
    private function isAllowed(BlacklistActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
