<?php

namespace Bixo\Lead\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Lead\Events\LeadAction as LeadActionEvent;
use Bixo\Lead\Notifications\LeadAction as LeadActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LeadAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LeadActionEvent.
     *
     * @param   LeadActionEvent  $event
     * @return mixed
     */
    public function handle(LeadActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $lead.
     *
     * @param   LeadActionEvent  $event
     * @return void
     */
    public function create(LeadActionEvent $event)
    {
        $client = $event->lead->client;
        Notification::send($client, new LeadActionNotification($event));
    }

    /**
     * Handle the LeadActionEvent as a listener.
     *
     * @param   LeadActionEvent  $event
     * @return mixed
     */
    public function asListener(LeadActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LeadActionEvent  $event
     * @return bool
     */
    private function isAllowed(LeadActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
