<?php
namespace Bixo\Lead\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Lead\Events\BlacklistAction as BlacklistActionEvent;
use Bixo\Lead\Models\Blacklist;

class BlacklistAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $blacklist;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param BlacklistActionEvent $blacklist
     */
    public function __construct(BlacklistActionEvent $blacklist)
    {
        $this->action = $event->action;
        $this->blacklist = $blacklist;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Blacklist Approved - ' . config('app.name'))
            ->view('lead::blacklist.email.action', ['data' => $this->blacklist]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
