<?php
namespace Bixo\Lead\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Lead\Events\LeadAction as LeadActionEvent;
use Bixo\Lead\Models\Lead;

class LeadAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $lead;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LeadActionEvent $lead
     */
    public function __construct(LeadActionEvent $lead)
    {
        $this->action = $event->action;
        $this->lead = $lead;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Lead Approved - ' . config('app.name'))
            ->view('lead::lead.email.action', ['data' => $this->lead]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
