<?php

namespace Bixo\Lead\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Lead\Models\Blacklist;

class BlacklistPolicy
{

    use BlacklistAction;
    use BlacklistWorkflow;

    /**
     * Determine if the given user can view the blacklist.
     *
     * @param Authenticatable $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function view(Authenticatable $user, Blacklist $blacklist)
    {
        if ($authUser->canDo('lead.blacklist.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $blacklist->is_owner;
    }

    /**
     * Determine if the given user can create a blacklist.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('lead.blacklist.create');
    }

    /**
     * Determine if the given user can update the given blacklist.
     *
     * @param Authenticatable $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function update(Authenticatable $user, Blacklist $blacklist)
    {
        if ($user->canDo('lead.blacklist.edit') && $user->isAdmin()) {
            return true;
        }

        return $blacklist->is_owner;
    }

    /**
     * Determine if the given user can delete the given blacklist.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Blacklist $blacklist)
    {
        return $blacklist->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
