<?php

namespace Bixo\Lead\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Lead\Models\Lead;

class LeadPolicy
{

    use LeadAction;
    use LeadReport;
    use LeadWorkflow;

    /**
     * Determine if the given user can view the lead.
     *
     * @param Authenticatable $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function view(Authenticatable $user, Lead $lead)
    {
        if ($authUser->canDo('lead.lead.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $lead->is_owner;
    }

    /**
     * Determine if the given user can create a lead.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('lead.lead.create');
    }

    /**
     * Determine if the given user can update the given lead.
     *
     * @param Authenticatable $user
     * @param Lead $lead
     *
     * @return bool
     */
    public function update(Authenticatable $user, Lead $lead)
    {
        if ($user->canDo('lead.lead.edit') && $user->isAdmin()) {
            return true;
        }

        return $lead->is_owner;
    }

    /**
     * Determine if the given user can delete the given lead.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Lead $lead)
    {
        return $lead->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
